from setuptools import setup

setup(name='sta_distributions11',
      version='0.1',
      description='Gaussian distributions',
      packages=['sta_distributions11'],
      author ='Chidume Jacob',
      author_email ='chidumejacob@gmail.com',
      zip_safe=False)
